@@ -1,6 +1,7 @@
 # coding=utf-8
 import sys
 import re
+import logging
 from lxml import etree
 from .ocr import Ocr
 from lxml.etree import tostring
@@ -16,7 +17,6 @@ class GetUI(object):
         self.ocr = None
         self.init_ocr()
         self.image = None
-        self.custom_xml_path = None  # 使用自定义的xml文件
 
     def init_ocr(self, app_id=None, secret_id=None, secret_key=None, keys=[]):
         self.keys = keys
@@ -64,8 +64,17 @@ class GetUI(object):
         :return: 
         """
         if is_update:
-            self.adb_ext.dump()  # 获取xml文件
-            self.__init_xml()
+            xml_str = None
+            for _ in range(5):
+                try:
+                    xml_str = self.adb_ext.dump()  # 获取xml文件
+                    self.__init_xml(xml_str)
+                    break
+                except etree.XMLSyntaxError:
+                    logging.error('etree.XMLSyntaxError:\n')
+                    if xml_str:
+                        logging.error(xml_str)
+                        logging.error('xml str:{}'.format(xml_str))
         xpath = xpath.decode('utf-8') if sys.version_info[0] < 3 else xpath
         elements = self.xml.xpath(xpath)
         uis = []
@@ -78,7 +87,10 @@ class GetUI(object):
         x1, y1, x2, y2 = re.compile(r"-?\d+").findall(bounds)
         ui = UI(self.adb_ext, x1, y1, x2, y2)
         ui.element = element
-        ui.text = element.get('text')
+        text = element.get('text')
+        if not text:
+            text = element.get('content-desc')
+        ui.text = text.encode('utf-8') if self.adb_ext.util.is_py2 and not isinstance(text, str) else text
         return ui
 
     def get_ui_by_ocr(self, text, is_contains=True, is_update=True):
@@ -124,12 +136,10 @@ class GetUI(object):
         if 'httpcode' in ocr_result and ocr_result['httpcode'] == 510:  # 如果依然频率限制，报错
             raise NameError('OCR 服务调用频率限制或者连接数限制，请使用自己申请的账号。')
 
-    def __init_xml(self):
-        if self.custom_xml_path is None:
-            xml_path = '{}.xml'.format(self.adb_ext.get_pc_temp_name())
-        else:
-            xml_path = self.custom_xml_path
-        self.xml = etree.parse(xml_path)
+    def __init_xml(self, xml_str):
+        if not isinstance(xml_str, str):
+            xml_str = xml_str.encode('utf-8')
+        self.xml = etree.fromstring(xml_str)
         for element in self.xml.findall('.//node'):
             element.tag = element.get('class').split('.')[-1].replace('$', '')  # 将每个node的name替换为class值，和uiautomator里显示的一致
 
